@@ -13,7 +13,7 @@ from .__version__ import (  # noqa: F401  imported but unused
 from .sync_client import Spotify  # noqa:  F401  imported but unused
 from .async_client import AsyncSpotify  # noqa:  F401  imported but unused
 from .utils import convert_from_iso_date  # noqa:  F401  imported but unused
-from .creds import (
+from .creds import (  # noqa:  F401  imported but unused
     ClientCreds,
     UserCreds,
     ALL_SCOPES,
